import { Canvas2DRenderer } from '@/assets/js/renderer_2d.js'

// 渲染,每个动画帧只能绘制一次
let renderer = null

class Queue {
  constructor() {
    this._items = []
  }

  enqueue(item) {
    this._items.push(item)
  }

  dequeue() {
    return this._items.shift()
  }

  head() {
    return this._items[0]
  }

  tail() {
    return this._items[this._items.length - 1]
  }

  isEmpty() {
    return !this._items.length
  }

  size() {
    return this._items.length
  }

  clear() {
    this._items = []
  }
}

var FrameBuffer = new Queue()

function renderFrame(frame) {
  FrameBuffer.enqueue(frame)
}

const decoder = new VideoDecoder({
  output(frame) {
    renderFrame(frame)
  },
  error(e) {
    console.error(e)
  }
})

var TimedRendering = setInterval(function () {
  if (FrameBuffer.size() > 0) {
    renderer.draw(FrameBuffer.dequeue())
  }
}, 39)

var flagPost = 0
// Listen for the start request.
self.addEventListener('message', (message) => {
  if (message.data.DataType === 'Start') {
    renderer = new Canvas2DRenderer(message.data.canvas)
    if (!VideoDecoder) throw new Error('The current browser does not support the VideoDecoder API')
  }
  if (message.data.DataType === 'Track') {
    decoder.configure({
      codec: message.data.codec,
      codedHeight: message.data.codedHeight,
      codedWidth: message.data.codedWidth,
      description: message.data.description
    })
    console.log(message.data);
  }
  if (message.data.DataType === 'Samples') {
    decoder.decode(
      new EncodedVideoChunk({
        type: message.data.type,
        timestamp: message.data.timestamp,
        duration: message.data.duration,
        data: message.data.data
      })
    )
    if (flagPost === 3) {
      var connect = true
      self.postMessage(connect)
      flagPost = 4
    } else {
      if (flagPost === 4) return
      flagPost++
    }
  }
})
