import { createRouter, createWebHistory, createWebHashHistory } from 'vue-router'
import { usePageTitle, useInitCookie } from './helper'
import storage from '@/utils/storage'

const whiteList = ['/login'] // 白名单
const router = createRouter({
  history: createWebHashHistory(import.meta.env.BASE_URL),
  routes: [
    {
      path: '/',
      redirect: '/video_monitoring/panoramic_situation'
    },
    {
      path: '/video_monitoring',
      name: 'VideoMonitoring',
      component: () => import('@/views/VideoMonitoring/VideoMonitoring.vue'),
      children: [
        {
          path: 'panoramic_situation',
          name: 'PanoramicSituation',
          meta: {
            title: '全景态势'
          },
          component: () =>
            import('@/views/VideoMonitoring/pages/PanoramicSituation/PanoramicSituation.vue')
        },
        {
          path: 'glance',
          name: 'Glance',
          meta: {
            title: '一点即视'
          },
          component: () => import('@/views/VideoMonitoring/pages/Glance/Glance.vue')
        },
        {
          path: 'device_management',
          name: 'DeviceManagement',
          meta: {
            title: '设备管理'
          },
          component: () => import('@/views/VideoMonitoring/pages/DeviceManagement/DeviceManagement.vue')
        },
        {
          path: 'tag_management',
          name: 'TagManagement',
          meta: {
            title: '标签管理'
          },
          component: () => import('@/views/VideoMonitoring/pages/TagManagement/TagManagement.vue')
        },
        {
          path: 'remote_playback',
          name: 'RemotePlayback',
          meta: {
            title: '远程回放'
          },
          component: () => import('@/views/VideoMonitoring/pages/RemotePlayback/RemotePlayback.vue')
        },
        {
          path: 'advanced_linkage',
          name: 'AdvancedLinkage',
          meta: {
            title: '高级联动'
          },
          component: () =>
            import('@/views/VideoMonitoring/pages/AdvancedLinkage/AdvancedLinkage.vue')
        }
      ]
    },
    // {
    //   path: '/login',
    //   name: 'Login',
    //   component: () => import('@/views/system/Login/Login.vue'),
    //   meta: {
    //     title: '登录'
    //   }
    // },
    // {
    //   path: '/tempone',
    //   name: 'TempOne',
    //   component: () => import('@/views/TempOne/TempOne.vue')
    // },
    {
      path: '/:pathMatch(.*)*',
      component: () => import('@/views/system/404/404.vue'),
      meta: {
        title: '找不到页面'
      }
    }
  ]
})

router.beforeEach((to, from, next) => {
  useInitCookie()
  usePageTitle(to)
  next()
  // // 登录并且设备已经选择
  // if (storage.session.get('t') && storage.session.get('d_info')) {
  //   if (to.name === 'Login') {
  //     next({ path: '/' })
  //   } else {
  //     next()
  //   }
  // } else {
  //   if (!whiteList.includes(to.path)) {
  //     next({ path: '/login' })
  //   } else {
  //     next()
  //   }
  // }
})

async function setupRouter(app) {
  app.use(router)
}

export { router, setupRouter }
