import { piniaStore } from '@/stores'
import { isWap } from '@/utils'
import storage from '@/utils/storage'
import dayjs from 'dayjs'
const {
  API_VIEW_PREVIEW_POST,
  API_LY_NVR_LIST_POST,
  API_VIEW_BC_GET,
  API_INFER_MODE_GET,
  API_LY_TRANSFER_GET,
  API_CLIP_INFO_GET
} = useRequest()

export const useSystemStore = defineStore('systemStore', {
  state: () => ({
    videoUrl: '', // 全景url
    qjHeight: '', // 全景缩放高度
    qjUUID: '', //全景uuid
    partObj: {}, //细节X Y
    videoArrange: {}, // 全景尺寸信息
    glanceUrl: '', // 一点即视url
    deviceInfo: JSON.parse(storage.session.get('d_info')) || {},
    ip:
      import.meta.env.VITE_APP_API_BASEURL === '/'
        ? window.location.origin
        : import.meta.env.VITE_APP_API_BASEURL,
    aiList: [], // ai报警信息列表
    inferMode: JSON.parse(storage.local.get('i_m')) || {}, // ai 报警 IP
    isClose: false, // 是否关闭全景
    isFull: false, // 是否全屏
    address: {}, // 当前位置天气
    videoSwitch: storage.local.get('v_switch') || 1, // 切换设备模式
    videoWorkerCache: {}, // 用户线程缓存
    canvasStyle: {}, // 画布样式
    winActive: 0, //窗口选中
    menuCom: {}, //菜单组件对应存储
    event: isWap() ? 'touchstart' : 'click', // 事件
    cilpInfo: {}, // 裁剪信息
    rtspVideo: '', // rtsp视频
    nvrId: '' // 硬盘录列id
  }),
  getters: {
    ipF() {
      return this.ip.split('//')[1]
    },
    badgeShow() {
      return this.aiList.some((item) => item.state != 1)
    }
  },
  actions: {
    async getVideoUrl(coordinate, type = 'Full') {
      this.videoUrl = `wss://${this.ip.split('//')[1]}/VideoShow/Preview/${type}/Main?X=${
        coordinate.X
      }&Y=${coordinate.Y}`
      return this.videoUrl
    },
    async getVideoArrange() {
      const cilpInfo = await API_CLIP_INFO_GET()
      Object.assign(this.videoArrange, {
        FullMainWidth: cilpInfo.W,
        FullMainHeight: cilpInfo.H
      })
      Object.assign(this.cilpInfo, cilpInfo)
      return cilpInfo
    },
    async getVideoTransfer() {
      // const res = await API_VIEW_BC_GET({ urlsrc: 'rtsp://admin:ubis3333@192.168.211.64:554/0' })
      return new Promise(async (resolve, reject) => {
        try {
          const res = await API_VIEW_BC_GET()
          this.glanceUrl = `wss://${this.ip.split('//')[1]}/VideoShow/Common?UUID=${res.wss}`
          resolve()
        } catch (e) {
          reject(e)
        }
      })
    },
    async getRTSPVideoTransfer(urlsrc) {
      const res = await API_LY_TRANSFER_GET({ urlsrc })
      this.rtspVideo = `wss://${this.ip.split('//')[1]}/VideoShow/Common?UUID=${res.UUID}`
      console.log(this.rtspVideo)
    },
    async loginOut(router) {
      storage.session.clear()
      storage.local.clear()
      router.replace('/login')
    },
    // 重置全景
    async resetQj(worker) {
      return new Promise((resolve) => {
        worker && worker.WebSocketWork.terminate() && worker.worker.terminate()
        this.isClose = true
        setTimeout(() => {
          this.isClose = false
          resolve()
        }, 100)
      })
    },
    // 连接报警信息
    async connectAlarmWS() {
      // setTimeout(() => {
      //   // const data = {
      //   //   AlarmTime: 1709274691,
      //   //   CfgId: 95,
      //   //   Type: 'human',
      //   //   SerialNumber: '5cc8e284-55c9-4916-b493-20a222d3386f',
      //   //   AlarmId: 1516,
      //   //   Res: {
      //   //     '16535ccf-ab52-4553-a494-f168f5144bd2%7C9%7C1546372969796': [
      //   //       { x: 525, y: 1775, w: 1615, h: 2067 }
      //   //     ],
      //   //     'd29e7346-8d8d-44ff-918b-ca0928687f75|0|1709628059861': [
      //   //       { x: 525, y: 1775, w: 1615, h: 2067 }
      //   //     ]
      //   //   }
      //   // }
      //   const data = {
      //     AlgorithmName: '人员计数D',
      //     CameraDeviceId: 12,
      //     src: '/20240618/20240618174105_510903_30_12_src.jpg?serverUUID=3f16a3b113234807b81f6f8d0f268232',
      //     time: 1718703665,
      //     h: 1146,
      //     w: 1271,
      //     x: 167,
      //     y: 1204
      //   }
      //   const { x, y, w, h, src } = data
      //   this.aiList.unshift({
      //     ...data,
      //     state: 0,
      //     Res: {
      //       [src]: [{ x, y, w, h }]
      //     },
      //     timeFormat: dayjs(parseInt(`${data.time}`.padEnd(13, '0'))).format('YYYY-MM-DD HH:mm:ss')
      //   })
      //   if (this.aiList.length >= 30) {
      //     this.aiList.splice(20, 10)
      //   }
      // }, 1000)

      let websocket
      let that = this
      ;(() => {
        websocket = new WebSocket(`wss://${this.ipF}/Ai/Alarm`)
        websocket.onopen = function (e) {
          console.log('/Ai/Alarm 连接已经建立')
        }
        websocket.onmessage = function (e) {
          const data = JSON.parse(e.data)
          const { x, y, w, h, src } = data
          that.aiList.unshift({
            ...data,
            state: 0,
            Res: {
              [src]: [{ x, y, w, h }]
            },
            timeFormat: dayjs(parseInt(`${data.time}`.padEnd(13, '0'))).format(
              'YYYY-MM-DD HH:mm:ss'
            )
          })
          if (that.aiList.length >= 100) {
            that.aiList.splice(50, 10)
          }
        }
        websocket.onerror = function (e) {
          console.log('Ai/Alarm 发生错误')
        }
        websocket.onclose = function (e) {
          console.log('Ai/Alarm 连接断开')
        }
      })()
    },
    async getInferMode() {
      const res = await API_INFER_MODE_GET()
      if (!res) return
      Object.assign(this.inferMode, res)
      storage.local.set('i_m', JSON.stringify(res))
      return res
    },
    async getNvrId() {
      const nvrId = await API_LY_NVR_LIST_POST()
      this.nvrId = Object.keys(nvrId)[0]
    }
  }
})

export function useOutsideSystemStore() {
  return useSystemStore(piniaStore)
}
